@@ -438,7 +438,7 @@ void asmem_update()
 {
 	time_t cur_time;
 	cur_time = time(0);
-	if ( (cur_time - last_time) >= state.update_interval ) {
+	if ( abs(cur_time - last_time) >= state.update_interval ) {
 		last_time = cur_time;
 		if (read_meminfo())
 			asmem_cleanup();
