@@ -298,13 +298,13 @@ void error_handle( int place, const char * message )
 		default :
 			printf("asmem: cannot open %s. Error %d: %s\n",
 				state.proc_mem_filename, errno,
-				sys_errlist[errno]);
+				strerror(errno));
 			break;
 		}
 		break;
 	default: /* catchall for the rest */
 		printf("asmem: %s: Error %d: %s\n",
-			message, errno, sys_errlist[errno]);
+			message, errno, strerror(errno));
 	}
 }
 
